@@ -3,12 +3,12 @@ from __future__ import annotations
 
 import sys
 
-from pydocstringformatter.utils.exceptions import (
+from pydocstringformatter._utils.exceptions import (
     ParsingError,
     PydocstringFormatterError,
 )
 
-__version__ = "0.6.0"
+__version__ = "0.7.0"
 
 
 def run_docstring_formatter(argv: list[str] | None = None) -> None:
